pub struct AssistantMessageEventStream { /* private fields */ }Expand description
A stream of assistant message events.
This wraps an async channel and provides:
- Async iteration over events via
Streamtrait - A
result()method to await the finalAssistantMessage
The stream is created by provider implementations and events are pushed
via the sender handle returned from AssistantMessageEventStream::new().
Implementations
Sourceimpl AssistantMessageEventStream
impl AssistantMessageEventStream
Sourcepub fn new() -> (Self, EventStreamSender)
pub fn new() -> (Self, EventStreamSender)
Create a new event stream and sender pair.
The sender is used by provider implementations to push events. The stream is returned to the caller for iteration.
Sourcepub async fn result(self) -> Result<AssistantMessage>
pub async fn result(self) -> Result<AssistantMessage>
Await the final result of the stream.
This consumes the result receiver, so it can only be called once.
Returns the final AssistantMessage when the stream completes.